from .client_platform import require_client_platform
from .rbac_voter import require_role
from .user_dependant import require_user
